**by Edgar Allan Poe**
*(published 1845)*

Once it smiled a silent dell
Where the people did not dwell;
They had gone unto the wars,
Trusting to the mild-eyed stars,
Nightly, from their azure towers,
To keep watch above the flowers,
In the midst of which all day
The red sun-light lazily lay.

Now each visitor shall confess
The sad valley's restlessness.
Nothing there is motionless --
Nothing save the airs that brood
Over the magic solitude.

Ah, by no wind are stirred those trees
That palpitate like the chill seas
Around the misty Hebrides!
Ah, by no wind those clouds are driven
That rustle through the unquiet Heaven
Uneasily, from morn till even,
Over the violets there that lie
In myriad types of the human eye --
Over the lilies there that wave
And weep above a nameless grave!

They wave: -- from out their fragrant tops
Eternal dews come down in drops.
They weep: -- from off their delicate stems
Perennial tears descend in gems.